@@ -252,9 +252,21 @@ COMMAND_FRIENDLY_NAME = {
     "ELECCON": "electrical_conductivity",
     "ELECRES": "electrical_resistivity",
     PROP_COMMS_ERROR: "device_communication_errors",
+    "ETO": "evapotranspiration",
+    "FATM": "fat_mass",
+    "FREQ": "frequency",
     "GPV": "general_purpose",
+    "GUST": "gust",
     "GV0": "custom_control_0",
     "GV1": "custom_control_1",
+    "GV2": "custom_control_2",
+    "GV3": "custom_control_3",
+    "GV4": "custom_control_4",
+    "GV5": "custom_control_5",
+    "GV6": "custom_control_6",
+    "GV7": "custom_control_7",
+    "GV8": "custom_control_8",
+    "GV9": "custom_control_9",
     "GV10": "custom_control_10",
     "GV11": "custom_control_11",
     "GV12": "custom_control_12",
@@ -265,42 +277,70 @@ COMMAND_FRIENDLY_NAME = {
     "GV17": "custom_control_17",
     "GV18": "custom_control_18",
     "GV19": "custom_control_19",
-    "GV2": "custom_control_2",
     "GV20": "custom_control_20",
-    "GV3": "custom_control_3",
-    "GV4": "custom_control_4",
-    "GV5": "custom_control_5",
-    "GV6": "custom_control_6",
-    "GV7": "custom_control_7",
-    "GV8": "custom_control_8",
-    "GV9": "custom_control_9",
+    "GV21": "custom_control_21",
+    "GV22": "custom_control_22",
+    "GV23": "custom_control_23",
+    "GV24": "custom_control_24",
+    "GV25": "custom_control_25",
+    "GV26": "custom_control_26",
+    "GV27": "custom_control_27",
+    "GV28": "custom_control_28",
+    "GV29": "custom_control_29",
+    "GV30": "custom_control_30",
     "GVOL": "gas_volume",
     "HAIL": "hail",
+    "HEATIX": "heat_index",
+    "HR": "heart_rate",
     "LUMIN": "luminance",
+    "METHANE": "methane_density",
     "MOIST": "moisture",
+    "MOON": "moon_phase",
+    "MUSCLEM": "muscle_mass",
+    "OZONE": "ozone",
     "PCNT": "pulse_count",
     "PF": "power_factor",
+    "PM10": "particulate_matter_10",
+    "PM25": "particulate_matter_2.5",
+    "POP": "percent_chance_of_precipitation",
     "PPW": "polarized_power",
+    "PRECIP": "precipitation",
     "PULSCNT": "pulse_count",
+    "RADON": "radon_concentration",
     "RAINRT": "rain_rate",
+    "RELMOD": "relative_modulation_level",
+    "RESPR": "respiratory_rate",
+    "RFSS": "rf_signal_strength",
     "ROTATE": "rotation",
     "RR": "ramp_rate",
     "SEISINT": "seismic_intensity",
     "SEISMAG": "seismic_magnitude",
+    "SMOKED": "smoke_density",
+    "SOILH": "soil_humidity",
+    "SOILR": "soil_reactivity",
+    "SOILS": "soil_salinity",
     "SOILT": "soil_temperature",
     "SOLRAD": "solar_radiation",
     "SPEED": "speed",
     "SVOL": "sound_volume",
     "TANKCAP": "tank_capacity",
+    "TEMPEXH": "exhaust_temperature",
+    "TEMPOUT": "outside_temperature",
     "TIDELVL": "tide_level",
+    "TIME": "time",
     "TIMEREM": "time_remaining",
     "TPW": "total_energy_used",
     "UAC": "user_number",
     "USRNUM": "user_number",
     "UV": "uv_light",
     "VOCLVL": "voc_level",
+    "WATERF": "water_flow",
+    "WATERP": "water_pressure",
     "WATERT": "water_temperature",
+    "WATERTB": "boiler_water_temperature",
+    "WATERTD": "domestic_hot_water_temperature",
     "WEIGHT": "weight",
+    "WINDCH": "wind_chill",
     "WINDDIR": "wind_direction",
     "WVOL": "water_volume",
     CMD_BEEP: "beep",
@@ -358,17 +398,18 @@ COMMAND_NAME = {val: key for key, val in COMMAND_FRIENDLY_NAME.items()}
 
 # Referenced from ISY-WSDK-5.0.4\WSDL\family.xsd
 NODE_FAMILY_ID = {
-    "0": "Default",
-    "1": "Insteon",
-    "2": "UPB",
-    "3": "RCS",
-    "4": "ZWave",
-    "5": "Auto DR",
-    "6": "Group",
-    "7": "UDI",
-    "8": "Brultech",
-    "9": "NCD",
-    "10": "Node Server",
+    FAMILY_CORE: "Default",
+    FAMILY_INSTEON: "Insteon",
+    FAMILY_UPB: "UPB",
+    FAMILY_RCS: "RCS",
+    FAMILY_ZWAVE: "Z-Wave",
+    FAMILY_AUTO: "Auto_DR",
+    FAMILY_GENERIC: "Group",
+    FAMILY_UDI: "UDI",
+    FAMILY_BRULTECH: "Brultech",
+    FAMILY_NCD: "NCD",
+    FAMILY_NODESERVER: "Node_Server",
+    FAMILY_ZMATTER_ZWAVE: "ZMatter_Z-Wave",
 }
 
 UOM_SECONDS = "57"
