@@ -3,6 +3,7 @@ import datetime
 import time
 
 from .constants import (
+    _LOGGER,
     ATTR_FORMATTED,
     ATTR_ID,
     ATTR_PRECISION,
@@ -43,7 +44,7 @@ def parse_xml_properties(xmldoc):
 
     props = xmldoc.getElementsByTagName(TAG_PROPERTY)
     if not props:
-        return state, aux_props
+        return state, aux_props, state_set
 
     for prop in props:
         prop_id = attr_from_element(prop, ATTR_ID)
@@ -73,7 +74,7 @@ def parse_xml_properties(xmldoc):
                 result.uom = UOM_SECONDS
             aux_props[prop_id] = result
 
-    return state, aux_props
+    return state, aux_props, state_set
 
 
 def value_from_xml(xml, tag_name, default=None):
@@ -176,7 +177,11 @@ class EventEmitter:
     def notify(self, event):
         """Notify a listener."""
         for subscriber in self._subscribers:
-            subscriber.callback(event)
+            # Guard against downstream errors interrupting the socket connection (#249)
+            try:
+                subscriber.callback(event)
+            except Exception:  # pylint: disable=broad-except
+                _LOGGER.exception("Error during callback of %s", event)
 
 
 class EventListener:
